@@ -5,11 +5,29 @@ use warnings;
 
 use IUP::Internal::LibraryIup;
 use IUP::Internal::Callback;
-use IUP::Internal::Attribute;
 use IUP::Constants qw(IUP_CURRENT);
 use Carp;
 use Scalar::Util qw(blessed looks_like_number);
 
+sub import {
+  my $p = shift;
+  #warn "### IUP::Internal::Element->import($p) called";
+
+  # callback accessors
+  if (my $c = IUP::Internal::Callback::_get_cb_eval_code($p)) {
+    eval($c);
+    die "###ERROR### import failed(cb) '$p': " . $@ if $@;
+  }
+}
+
+sub AUTOLOAD {
+  my ($name) = our $AUTOLOAD =~ /::(\w+)$/;
+  die "FATAL: unknown method '$name'" unless $name =~ /^[A-Z0-9_]+$/;
+  splice(@_, 1, 0, $name);
+  goto &SetAttribute if scalar(@_)>2;
+  goto &GetAttribute;
+}
+
 sub BEGIN {
   #warn "***DEBUG*** IUP::Internal::Element::BEGIN() started\n";
   IUP::Internal::LibraryIup::_IupControlsOpen();
@@ -97,24 +115,6 @@ sub ihandle {
   }
 }
 
-sub import {
-  my $p = shift;
-  #warn "### IUP::Internal::Element->import($p) called";
-
-  # callback accessors
-  if (my $c = IUP::Internal::Callback::_get_cb_eval_code($p)) {
-    eval($c);
-    die "###ERROR### import failed(cb) '$p': " . $@ if $@;
-  }
-  
-  # attribute accessors
-  if (my $a = IUP::Internal::Attribute::_get_attr_eval_code($p)) {
-    eval($a);
-    die "###ERROR### import failed(attr) '$p': " . $@ if $@;
-  }
-  
-}
-
 sub GetName {
   #char* IupGetName(Ihandle* ih); [in C]
   #iup.GetName(ih: ihandle) -> (name: string) [in Lua]
@@ -181,11 +181,23 @@ sub GetAttribute {
   #char *IupGetAttribute(Ihandle *ih, const char *name); [in C]
   #iup.GetAttribute(ih: ihandle, name: string) -> value: string [in Lua]
   my ($self, @names) = @_;
-  my @rv = ();  
+  my @rv = ();
   push(@rv, IUP::Internal::LibraryIup::_IupGetAttribute($self->ihandle, $_)) for (@names);    
   return (scalar(@names) == 1) ? $rv[0] : @rv; #xxxCHECKLATER not sure if this is a good idea
 }
 
+sub GetAttributeAsElement {
+  #special perl method
+  #XXX-FIXME needs testin g
+  my ($self, @names) = @_;
+  my @rv = ();
+  for (@names) {
+    my $v = IUP::Internal::LibraryIup::_IupGetAttribute($self->ihandle, $_);
+    push(@rv, defined $v ? IUP->GetByName($v) : undef);    
+  }
+  return (scalar(@names) == 1) ? $rv[0] : @rv; #xxxCHECKLATER not sure if this is a good idea
+}
+
 sub GetAttributeId {
   #char *IupGetAttributeId(Ihandle *ih, const char *name, int id); [in C]
   #iup.GetAttributeId(ih: ihandle, name: string, id: number) -> value: string [in Lua]
@@ -662,7 +674,7 @@ sub _proc_child_param_single {
 
 1;
 
-__END__
+=pod
 
 =head1 NAME
 
